===============
DummyIaasDriver
===============

``DummyIaasDriver`` is used only for simulation and development.
It doesn't need any configuration.
It has all required methods implemented, with the state kept inside the driver's internal structures (in memory).

